==> sslexplorer-0.2.13-src.tar.gz: sslexplorer-0.2.13/sslexplorer/src/com/sslexplorer/install/forms/ConfigureSuperUserForm.java <==
/*
 *  SSL-Explorer
 *
 *  Copyright (C) 2003-2006 3SP LTD. All Rights Reserved
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
			
package com.sslexplorer.install.forms;

import java.util.ArrayList;
import java.util.Calendar;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.Globals;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;

import com.sslexplorer.core.CoreServlet;
import com.sslexplorer.core.UserDatabaseManager;
import com.sslexplorer.properties.Property;
import com.sslexplorer.properties.impl.realms.RealmKey;
import com.sslexplorer.realms.DefaultRealm;
import com.sslexplorer.realms.Realm;
import com.sslexplorer.security.User;
import com.sslexplorer.security.UserDatabase;
import com.sslexplorer.wizard.AbstractWizardSequence;
import com.sslexplorer.wizard.forms.DefaultWizardForm;


/**
 * Wizard for for selecting and configuring the super user account to
 * use.
 * 
 * @author Brett Smith <a href="mailto: brett@3sp.com">&lt;brett@3sp.com&gt;</a>
 */
public class ConfigureSuperUserForm extends DefaultWizardForm {

    final static Log log = LogFactory.getLog(ConfigureSuperUserForm.class);

    /**
     * Super user password
     */
    public final static String ATTR_SUPER_USER_PASSWORD = "superUserPassword";
    
    /**
     * Super user password
     */
    public final static String ATTR_SUPER_USER = "account";
    
    /**
     * Super user email
     */
    public final static String ATTR_SUPER_USER_EMAIL = "email";

    // Statics
    final static String DUMMY_PASSWORD = "**********";

    // Private instance variables
    private String confirmSuperUserPassword;
    private String superUserPassword;
    private String account;
    private String email;
    private List<String> usernames;
    private UserDatabase userDatabase;

    /**
     * Constructor.
     *
     */
    public ConfigureSuperUserForm() {
        super(true, true, "/WEB-INF/jsp/content/install/configureSuperUser.jspf", "account", false, false, "configureSuperUser",
            "install", "installation.configureSuperUser", 3);
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.sslexplorer.wizard.forms.AbstractWizardForm#init(com.sslexplorer.wizard.AbstractWizardSequence)
     */
    public void init(AbstractWizardSequence sequence, HttpServletRequest request) throws Exception {

    	userDatabase = (UserDatabase)sequence.getAttribute(SelectUserDatabaseForm.ATTR_USER_DATABASE_INSTANCE, null);
    	
        // Temporarily load the selected user database
        try {
        	if(!userDatabase.isOpen()) {
        		log.info("Opening user databse");
            	Calendar now = Calendar.getInstance();
                Realm realm = new DefaultRealm((String)sequence.getAttribute(SelectUserDatabaseForm.ATTR_USER_DATABASE, null), 1, UserDatabaseManager.DEFAULT_REALM_NAME, UserDatabaseManager.DEFAULT_REALM_DESCRIPTION, now, now);
        		userDatabase.open(CoreServlet.getServlet(), realm);
        	}
        	
            String bestGuess = null;
            String actualEmail = "";
            String firstEmail = null;
            boolean found = false;
            account = Property.getProperty(new RealmKey("security.administrators", userDatabase.getRealm().getResourceId()));
            email = "";
            User[] users = userDatabase.listAllUsers("*");
            usernames = new ArrayList<String>();
            if (users != null) {
                for (int i = 0; i < users.length; i++) {
                    String un = users[i].getPrincipalName();
                    usernames.add(un);
                    if(i == 0) {
                        firstEmail = users[i].getEmail();
                    }
                    if(un.equals(account)) {
                        actualEmail = users[i].getEmail();
                        found = true;
                    }
                    else if (un.toLowerCase().startsWith("admin") || un.toLowerCase().startsWith("root")) {
                        bestGuess  = un;
                        actualEmail = users[i].getEmail();
                    } 
                }
            }
            if(!found) {
                if(bestGuess != null) {
                    account = bestGuess;
                    email = actualEmail;
                }
                else if (usernames.size() > 0) {
                    account = (String) usernames.get(0);
                    email = firstEmail;
                }
                else {
                    account = "";
                    email = "";
                }
            }
            else {
                email = actualEmail;
            }
        } catch (Exception e) {
            log.error("Failed to load user database.", e);
        }

        /* DUMMY_PASSWORD is sent back because we don't want password
         * values sent back in HTML
         */
        String password = (String) sequence.getAttribute(ATTR_SUPER_USER_PASSWORD, "");
        if (!password.equals("")) {
            superUserPassword = DUMMY_PASSWORD;
            confirmSuperUserPassword = DUMMY_PASSWORD;
        } else {
            superUserPassword = "";
            confirmSuperUserPassword = "";
        }
        account = (String) sequence.getAttribute(ATTR_SUPER_USER, account);
        email = (String) sequence.getAttribute(ATTR_SUPER_USER_EMAIL, email);
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.sslexplorer.wizard.forms.AbstractWizardForm#apply(com.sslexplorer.wizard.AbstractWizardSequence)
     */
    public void apply(AbstractWizardSequence sequence) throws Exception {
        String password = null;
        if (DUMMY_PASSWORD.equals(superUserPassword)) {
            password = (String) sequence.getAttribute(ATTR_SUPER_USER_PASSWORD, "");
        } else {
            password = superUserPassword;
        }
        sequence.putAttribute(ATTR_SUPER_USER_PASSWORD, password);
        sequence.putAttribute(ATTR_SUPER_USER, account);
        sequence.putAttribute(ATTR_SUPER_USER_EMAIL, email);
    }

    /**
     * Set the super user password
     * 
     * @param superUserPassword super user password
     */
    public void setSuperUserPassword(String superUserPassword) {
        this.superUserPassword = superUserPassword;
    }

    /**
     * Get the super user password
     * 
     * @return super user password
     */
    public String getSuperUserPassword() {
        return superUserPassword;
    }

    /**
     * Set the confirmed super user password
     * 
     * @param confirmSuperUserPassword confirmed super user password
     */
    public void setConfirmSuperUserPassword(String confirmSuperUserPassword) {
        this.confirmSuperUserPassword = confirmSuperUserPassword;
    }

    /**
     * Get the confirmed super user password
     * 
     * @return confirmed super user password
     */
    public String getConfirmSuperUserPassword() {
        return confirmSuperUserPassword;
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.apache.struts.action.ActionForm#validate(org.apache.struts.action.ActionMapping,
     *      javax.servlet.http.HttpServletRequest)
     */
    public ActionErrors validate(ActionMapping mapping, HttpServletRequest request) {
        if (isCommiting() && superUserPassword != null) {
            try {
                // keypasswords do not match
                if (!( superUserPassword.equals(DUMMY_PASSWORD) && confirmSuperUserPassword.equals(DUMMY_PASSWORD)) && !superUserPassword.equals(confirmSuperUserPassword)) {
                    throw new Exception("passwordsDoNotMatch");
                }
                if (account.equals("")) {
                    throw new Exception("noSuperUserSpecified");
                } 
                try {
                    userDatabase.getAccount(account);
                } catch (Exception e) {
                    if (userDatabase.supportsAccountCreation()) {
                        if (superUserPassword.equals("")) {
                            throw new Exception("noPassword");
                        }
                    }
                    else {
                        throw new Exception("superUserDoesntExist");
                    }
                }
            } catch (Exception e) {
                // Always report to user when an error is encountered
                ActionErrors errs = new ActionErrors();
                errs.add(Globals.ERROR_KEY, new ActionMessage("installation.configureSuperUser.error." + e.getMessage()));
                return errs;
            }
        }
        return null;
    }

    /**
     * Get the super user account name
     * 
     * @return super user account name
     */
    public String getAccount() {
        return account;
    }

    /**
     * Get the super user account email address
     * 
     * @return super user account email address
     */
    public String getEmail() {
        return email;
    }

    /**
     * Set the super user account name
     * 
     * @param account super user account name
     */
    public void setAccount(String account) {
        this.account = account;
    }

    /**
     * Set the super user account email address
     * 
     * @param email super user account email address
     */
    public void setEmail(String email) {
        this.email = email;
    }

    /**
     * @return Returns the userDatabase.
     */
    public UserDatabase getUserDatabase() {
        return userDatabase;
    }

    /**
     * Get if account creation is supported by the current user
     * database. For this the underlying user database implementation
     * must support both account creation and password change
     * 
     * @return account creation supported by current user database
     */
    public boolean getSuperUserCreationSupported() {
        return userDatabase != null && userDatabase.supportsAccountCreation()
            && userDatabase.supportsPasswordChange();
    }
}

==> sslexplorer-0.2.15_01-src.tar.gz: sslexplorer-0.2.15_01/sslexplorer/src/com/sslexplorer/install/forms/ConfigureSuperUserForm.java <==
/*
 *  SSL-Explorer
 *
 *  Copyright (C) 2003-2006 3SP LTD. All Rights Reserved
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
			
package com.sslexplorer.install.forms;

import java.util.ArrayList;
import java.util.Calendar;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.Globals;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;

import com.sslexplorer.core.CoreServlet;
import com.sslexplorer.core.UserDatabaseManager;
import com.sslexplorer.jdbc.JDBCUserDatabase;
import com.sslexplorer.properties.Property;
import com.sslexplorer.properties.impl.realms.RealmKey;
import com.sslexplorer.realms.DefaultRealm;
import com.sslexplorer.realms.Realm;
import com.sslexplorer.security.User;
import com.sslexplorer.security.UserDatabase;
import com.sslexplorer.wizard.AbstractWizardSequence;
import com.sslexplorer.wizard.forms.DefaultWizardForm;


/**
 * Wizard for for selecting and configuring the super user account to
 * use.
 * 
 * @author Brett Smith <a href="mailto: brett@3sp.com">&lt;brett@3sp.com&gt;</a>
 */
public class ConfigureSuperUserForm extends DefaultWizardForm {

    final static Log log = LogFactory.getLog(ConfigureSuperUserForm.class);

    /**
     * Super user password
     */
    public final static String ATTR_SUPER_USER_PASSWORD = "superUserPassword";
    
    /**
     * Super user password
     */
    public final static String ATTR_SUPER_USER = "account";
    
    /**
     * Super user email
     */
    public final static String ATTR_SUPER_USER_EMAIL = "email";

    // Statics
    final static String DUMMY_PASSWORD = "**********";

    // Private instance variables
    private String confirmSuperUserPassword;
    private String superUserPassword;
    private String account;
    private String email;
    private List<String> usernames;
    private String databaseType;
    private UserDatabase userDatabase;

    /**
     * Constructor.
     *
     */
    public ConfigureSuperUserForm() {
        super(true, true, "/WEB-INF/jsp/content/install/configureSuperUser.jspf", "account", false, false, "configureSuperUser",
            "install", "installation.configureSuperUser", 3);
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.sslexplorer.wizard.forms.AbstractWizardForm#init(com.sslexplorer.wizard.AbstractWizardSequence)
     */
    public void init(AbstractWizardSequence sequence, HttpServletRequest request) throws Exception {
        databaseType = (String) sequence.getAttribute(SelectUserDatabaseForm.ATTR_USER_DATABASE, JDBCUserDatabase.DATABASE_TYPE);
        userDatabase = (UserDatabase) sequence.getAttribute(SelectUserDatabaseForm.ATTR_USER_DATABASE_INSTANCE, null);
    	
        // Temporarily load the selected user database
        try {
        	if(!userDatabase.isOpen()) {
        		log.info("Opening user databse");
            	Calendar now = Calendar.getInstance();
                Realm realm = new DefaultRealm((String)sequence.getAttribute(SelectUserDatabaseForm.ATTR_USER_DATABASE, null), 1, UserDatabaseManager.DEFAULT_REALM_NAME, UserDatabaseManager.DEFAULT_REALM_DESCRIPTION, now, now);
        		userDatabase.open(CoreServlet.getServlet(), realm);
        	}
        	
            String bestGuess = null;
            String actualEmail = "";
            String firstEmail = null;
            boolean found = false;
            account = Property.getProperty(new RealmKey("security.administrators", userDatabase.getRealm().getResourceId()));
            email = "";
            User[] users = userDatabase.listAllUsers("*");
            usernames = new ArrayList<String>();
            if (users != null) {
                for (int i = 0; i < users.length; i++) {
                    String un = users[i].getPrincipalName();
                    usernames.add(un);
                    if(i == 0) {
                        firstEmail = users[i].getEmail();
                    }
                    if(un.equals(account)) {
                        actualEmail = users[i].getEmail();
                        found = true;
                    }
                    else if (un.toLowerCase().startsWith("admin") || un.toLowerCase().startsWith("root")) {
                        bestGuess  = un;
                        actualEmail = users[i].getEmail();
                    } 
                }
            }
            if(!found) {
                if(bestGuess != null) {
                    account = bestGuess;
                    email = actualEmail;
                }
                else if (usernames.size() > 0) {
                    account = (String) usernames.get(0);
                    email = firstEmail;
                }
                else {
                    account = "";
                    email = "";
                }
            }
            else {
                email = actualEmail;
            }
        } catch (Exception e) {
            log.error("Failed to load user database.", e);
        }

        /* DUMMY_PASSWORD is sent back because we don't want password
         * values sent back in HTML
         */
        String password = (String) sequence.getAttribute(ATTR_SUPER_USER_PASSWORD, "");
        if (!password.equals("")) {
            superUserPassword = DUMMY_PASSWORD;
            confirmSuperUserPassword = DUMMY_PASSWORD;
        } else {
            superUserPassword = "";
            confirmSuperUserPassword = "";
        }
        account = (String) sequence.getAttribute(ATTR_SUPER_USER, account);
        email = (String) sequence.getAttribute(ATTR_SUPER_USER_EMAIL, email);
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.sslexplorer.wizard.forms.AbstractWizardForm#apply(com.sslexplorer.wizard.AbstractWizardSequence)
     */
    public void apply(AbstractWizardSequence sequence) throws Exception {
        String password = getSuperUserPassword(sequence);
        sequence.putAttribute(ATTR_SUPER_USER_PASSWORD, password);
        sequence.putAttribute(ATTR_SUPER_USER, account);
        sequence.putAttribute(ATTR_SUPER_USER_EMAIL, email);
    }
    
    private String getSuperUserPassword(AbstractWizardSequence sequence) {
        if(!getSuperUserCreationSupported()) {
            return "";
        }
        
        if (DUMMY_PASSWORD.equals(superUserPassword)) {
            return (String) sequence.getAttribute(ATTR_SUPER_USER_PASSWORD, "");
        } else {
            return superUserPassword;
        }      
    }

    /**
     * Set the super user password
     * 
     * @param superUserPassword super user password
     */
    public void setSuperUserPassword(String superUserPassword) {
        this.superUserPassword = superUserPassword;
    }

    /**
     * Get the super user password
     * 
     * @return super user password
     */
    public String getSuperUserPassword() {
        return superUserPassword;
    }

    /**
     * Set the confirmed super user password
     * 
     * @param confirmSuperUserPassword confirmed super user password
     */
    public void setConfirmSuperUserPassword(String confirmSuperUserPassword) {
        this.confirmSuperUserPassword = confirmSuperUserPassword;
    }

    /**
     * Get the confirmed super user password
     * 
     * @return confirmed super user password
     */
    public String getConfirmSuperUserPassword() {
        return confirmSuperUserPassword;
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.apache.struts.action.ActionForm#validate(org.apache.struts.action.ActionMapping,
     *      javax.servlet.http.HttpServletRequest)
     */
    public ActionErrors validate(ActionMapping mapping, HttpServletRequest request) {
        if (isCommiting() && superUserPassword != null) {
            try {
                // keypasswords do not match
                if (!( superUserPassword.equals(DUMMY_PASSWORD) && confirmSuperUserPassword.equals(DUMMY_PASSWORD)) && !superUserPassword.equals(confirmSuperUserPassword)) {
                    throw new Exception("passwordsDoNotMatch");
                }
                if (account.equals("")) {
                    throw new Exception("noSuperUserSpecified");
                } 
                try {
                    userDatabase.getAccount(account);
                } catch (Exception e) {
                    log.error("Failure to getAccount", e);
                    
                    if (getSuperUserCreationSupported()) {
                        if (superUserPassword.equals("")) {
                            throw new Exception("noPassword");
                        }
                    }
                    else {
                        throw new Exception("superUserDoesntExist");
                    }
                }
            } catch (Exception e) {
                // Always report to user when an error is encountered
                ActionErrors errs = new ActionErrors();
                errs.add(Globals.ERROR_KEY, new ActionMessage("installation.configureSuperUser.error." + e.getMessage()));
                return errs;
            }
        }
        return null;
    }

    /**
     * Get the super user account name
     * 
     * @return super user account name
     */
    public String getAccount() {
        return account;
    }

    /**
     * Get the super user account email address
     * 
     * @return super user account email address
     */
    public String getEmail() {
        return email;
    }

    /**
     * Set the super user account name
     * 
     * @param account super user account name
     */
    public void setAccount(String account) {
        this.account = account;
    }

    /**
     * Set the super user account email address
     * 
     * @param email super user account email address
     */
    public void setEmail(String email) {
        this.email = email;
    }

    /**
     * @return Returns the userDatabase.
     */
    public UserDatabase getUserDatabase() {
        return userDatabase;
    }

    /**
     * Get if account creation is supported by the current user
     * database. For this the underlying user database implementation
     * must support both account creation and password change
     * 
     * @return account creation supported by current user database
     */
    public boolean getSuperUserCreationSupported() {
        return JDBCUserDatabase.DATABASE_TYPE.equals(databaseType);
    }
}
